summaryrefslogtreecommitdiffstats
path: root/toolkit/mozapps/extensions/test/browser/browser_html_scroll_restoration.js
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-06-12 05:35:37 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-06-12 05:35:37 +0000
commita90a5cba08fdf6c0ceb95101c275108a152a3aed (patch)
tree532507288f3defd7f4dcf1af49698bcb76034855 /toolkit/mozapps/extensions/test/browser/browser_html_scroll_restoration.js
parentAdding debian version 126.0.1-1. (diff)
downloadfirefox-a90a5cba08fdf6c0ceb95101c275108a152a3aed.tar.xz
firefox-a90a5cba08fdf6c0ceb95101c275108a152a3aed.zip
Merging upstream version 127.0.
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'toolkit/mozapps/extensions/test/browser/browser_html_scroll_restoration.js')
-rw-r--r--toolkit/mozapps/extensions/test/browser/browser_html_scroll_restoration.js14
1 files changed, 9 insertions, 5 deletions
diff --git a/toolkit/mozapps/extensions/test/browser/browser_html_scroll_restoration.js b/toolkit/mozapps/extensions/test/browser/browser_html_scroll_restoration.js
index e4d88bc19a..76471007ec 100644
--- a/toolkit/mozapps/extensions/test/browser/browser_html_scroll_restoration.js
+++ b/toolkit/mozapps/extensions/test/browser/browser_html_scroll_restoration.js
@@ -91,11 +91,15 @@ async function waitForStableLayout(win) {
}
function isLayoutStable(win) {
- // <message-bar> elements may affect the layout of a page, and therefore we
- // should check whether its embedded style sheet has finished loading.
- for (let bar of win.document.querySelectorAll("message-bar")) {
- // Check for the existence of a CSS property from message-bar.css.
- if (!win.getComputedStyle(bar).getPropertyValue("--message-bar-icon-url")) {
+ // <moz-message-bar> elements may affect the layout of a page, and therefore
+ // we should check whether its embedded style sheet has finished loading.
+ for (let bar of win.document.querySelectorAll("moz-message-bar")) {
+ // Check for the existence of a CSS property from moz-message-bar.css.
+ if (
+ !win
+ .getComputedStyle(bar)
+ .getPropertyValue("--message-bar-background-color")
+ ) {
return false;
}
}